==> pam_flutter-1.3.27.tar.gz: lib/widgets/consent_language.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:pam_flutter/models/consent_message_model.dart';

class ConsentLanguage extends StatefulWidget {
  final String language;
  final bool isActive;
  final ConsentMessageStyleConfigurationConsentDetailModel? style;
  final Function(String lang) onClick;
  final bool? isFirst;
  final bool? isLast;

  ConsentLanguage({
    required this.language,
    required this.isActive,
    required this.style,
    required this.onClick,
    this.isFirst,
    this.isLast,
  });

  @override
  State<StatefulWidget> createState() {
    return _ConsentLanguageState();
  }
}

class _ConsentLanguageState extends State<ConsentLanguage> {
  BoxDecoration getBoxDecoration() {
    BoxDecoration decoration = BoxDecoration();

    if (widget.isFirst != null) {
      if (widget.isFirst!) {
        decoration = decoration.copyWith(
          color: Colors.grey.shade300,
          borderRadius: BorderRadius.only(
            topLeft: Radius.circular(8),
            bottomLeft: Radius.circular(8),
          ),
          border: Border.all(
            color: Colors.grey.shade300,
          ),
        );
      }
    } else if (widget.isLast != null) {
      if (widget.isLast!) {
        decoration = decoration.copyWith(
          color: Colors.grey.shade300,
          borderRadius: BorderRadius.only(
            topRight: Radius.circular(8),
            bottomRight: Radius.circular(8),
          ),
          border: Border.all(
            color: Colors.grey.shade300,
          ),
        );
      }
    } else {
      decoration = decoration.copyWith(
        color: Colors.grey.shade300,
        border: Border.all(
          color: Colors.grey.shade300,
        ),
      );
    }

    if(widget.isActive){
      decoration = decoration.copyWith(
        color: Colors.white,
        border: Border.all(
          color: widget.style?.PrimaryColor ?? Colors.deepOrange,
        ),
      );
    }

    return decoration;
  }

  @override
  Widget build(BuildContext context) {
    return GestureDetector(
      onTap: (){
        widget.onClick(widget.language);
      },
      child: Container(
        width: 50,
        alignment: Alignment.center,
        decoration: this.getBoxDecoration(),
        padding: EdgeInsets.only(
          top: 12,
          bottom: 12,
          left: 8,
          right: 8,
        ),
        child: Text(
          widget.language.toUpperCase(),
          style: TextStyle(
            color: widget.style?.PrimaryColor ?? Colors.deepOrange,
            fontWeight: FontWeight.bold,
          ),
        ),
      ),
    );
  }
}

==> pam_flutter-1.3.30.tar.gz: lib/widgets/consent_language.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:pam_flutter/models/consent_message_model.dart';

class ConsentLanguage extends StatefulWidget {
  final String language;
  final bool isActive;
  final ConsentMessageStyleConfigurationConsentDetailModel? style;
  final Function(String lang) onClick;
  final bool? isFirst;
  final bool? isLast;

  ConsentLanguage({
    required this.language,
    required this.isActive,
    required this.style,
    required this.onClick,
    this.isFirst,
    this.isLast,
  });

  @override
  State<StatefulWidget> createState() {
    return _ConsentLanguageState();
  }
}

class _ConsentLanguageState extends State<ConsentLanguage> {
  @override
  void initState() {
    super.initState();

    print(widget.language);
    print(widget.isFirst);
    print(widget.isLast);
    print(widget.isActive);
    print("==========");
  }

  BoxDecoration getBoxDecoration() {
    BoxDecoration decoration = BoxDecoration(
      color: Colors.grey.shade300,
      border: Border.all(
        color: Colors.grey.shade300,
      ),
    );

    if (widget.isFirst != null) {
      if (widget.isFirst!) {
        decoration = decoration.copyWith(
          borderRadius: BorderRadius.only(
            topLeft: Radius.circular(8),
            bottomLeft: Radius.circular(8),
          ),
        );
      }
    } else if (widget.isLast != null) {
      if (widget.isLast!) {
        decoration = decoration.copyWith(
          borderRadius: BorderRadius.only(
            topRight: Radius.circular(8),
            bottomRight: Radius.circular(8),
          ),
        );
      }
    }

    if(widget.isActive){
      decoration = decoration.copyWith(
        color: Colors.white,
        border: Border.all(
          color: widget.style?.PrimaryColor ?? Colors.deepOrange,
        ),
      );
    }

    return decoration;
  }

  @override
  Widget build(BuildContext context) {
    return GestureDetector(
      onTap: (){
        widget.onClick(widget.language);
      },
      child: Container(
        width: 50,
        alignment: Alignment.center,
        decoration: this.getBoxDecoration(),
        padding: EdgeInsets.only(
          top: 12,
          bottom: 12,
          left: 8,
          right: 8,
        ),
        child: Text(
          widget.language.toUpperCase(),
          style: TextStyle(
            color: widget.style?.PrimaryColor ?? Colors.deepOrange,
            fontWeight: FontWeight.bold,
          ),
        ),
      ),
    );
  }
}
